# Stubs for google.ads.google_ads.v6.services.enums (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class _CreateEnumTypeUponFirstAccess:
    def __getattribute__(self, name: Any): ...

class AccessInvitationErrorEnum(_CreateEnumTypeUponFirstAccess):
    AccessInvitationError: str = ...

class AccessReasonEnum(_CreateEnumTypeUponFirstAccess):
    AccessReason: str = ...

class AccessRoleEnum(_CreateEnumTypeUponFirstAccess):
    AccessRole: str = ...

class AccountBudgetProposalErrorEnum(_CreateEnumTypeUponFirstAccess):
    AccountBudgetProposalError: str = ...

class AccountBudgetProposalStatusEnum(_CreateEnumTypeUponFirstAccess):
    AccountBudgetProposalStatus: str = ...

class AccountBudgetProposalTypeEnum(_CreateEnumTypeUponFirstAccess):
    AccountBudgetProposalType: str = ...

class AccountBudgetStatusEnum(_CreateEnumTypeUponFirstAccess):
    AccountBudgetStatus: str = ...

class AccountLinkErrorEnum(_CreateEnumTypeUponFirstAccess):
    AccountLinkError: str = ...

class AccountLinkStatusEnum(_CreateEnumTypeUponFirstAccess):
    AccountLinkStatus: str = ...

class AdCustomizerErrorEnum(_CreateEnumTypeUponFirstAccess):
    AdCustomizerError: str = ...

class AdCustomizerPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    AdCustomizerPlaceholderField: str = ...

class AdDestinationTypeEnum(_CreateEnumTypeUponFirstAccess):
    AdDestinationType: str = ...

class AdErrorEnum(_CreateEnumTypeUponFirstAccess):
    AdError: str = ...

class AdGroupAdErrorEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupAdError: str = ...

class AdGroupAdRotationModeEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupAdRotationMode: str = ...

class AdGroupAdStatusEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupAdStatus: str = ...

class AdGroupBidModifierErrorEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupBidModifierError: str = ...

class AdGroupCriterionApprovalStatusEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupCriterionApprovalStatus: str = ...

class AdGroupCriterionErrorEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupCriterionError: str = ...

class AdGroupCriterionStatusEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupCriterionStatus: str = ...

class AdGroupErrorEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupError: str = ...

class AdGroupFeedErrorEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupFeedError: str = ...

class AdGroupStatusEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupStatus: str = ...

class AdGroupTypeEnum(_CreateEnumTypeUponFirstAccess):
    AdGroupType: str = ...

class AdNetworkTypeEnum(_CreateEnumTypeUponFirstAccess):
    AdNetworkType: str = ...

class AdParameterErrorEnum(_CreateEnumTypeUponFirstAccess):
    AdParameterError: str = ...

class AdServingOptimizationStatusEnum(_CreateEnumTypeUponFirstAccess):
    AdServingOptimizationStatus: str = ...

class AdSharingErrorEnum(_CreateEnumTypeUponFirstAccess):
    AdSharingError: str = ...

class AdStrengthEnum(_CreateEnumTypeUponFirstAccess):
    AdStrength: str = ...

class AdTypeEnum(_CreateEnumTypeUponFirstAccess):
    AdType: str = ...

class AdvertisingChannelSubTypeEnum(_CreateEnumTypeUponFirstAccess):
    AdvertisingChannelSubType: str = ...

class AdvertisingChannelTypeEnum(_CreateEnumTypeUponFirstAccess):
    AdvertisingChannelType: str = ...

class AdxErrorEnum(_CreateEnumTypeUponFirstAccess):
    AdxError: str = ...

class AffiliateLocationFeedRelationshipTypeEnum(_CreateEnumTypeUponFirstAccess):
    AffiliateLocationFeedRelationshipType: str = ...

class AffiliateLocationPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    AffiliateLocationPlaceholderField: str = ...

class AgeRangeTypeEnum(_CreateEnumTypeUponFirstAccess):
    AgeRangeType: str = ...

class AppCampaignAppStoreEnum(_CreateEnumTypeUponFirstAccess):
    AppCampaignAppStore: str = ...

class AppCampaignBiddingStrategyGoalTypeEnum(_CreateEnumTypeUponFirstAccess):
    AppCampaignBiddingStrategyGoalType: str = ...

class AppPaymentModelTypeEnum(_CreateEnumTypeUponFirstAccess):
    AppPaymentModelType: str = ...

class AppPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    AppPlaceholderField: str = ...

class AppStoreEnum(_CreateEnumTypeUponFirstAccess):
    AppStore: str = ...

class AppUrlOperatingSystemTypeEnum(_CreateEnumTypeUponFirstAccess):
    AppUrlOperatingSystemType: str = ...

class AssetErrorEnum(_CreateEnumTypeUponFirstAccess):
    AssetError: str = ...

class AssetFieldTypeEnum(_CreateEnumTypeUponFirstAccess):
    AssetFieldType: str = ...

class AssetLinkErrorEnum(_CreateEnumTypeUponFirstAccess):
    AssetLinkError: str = ...

class AssetLinkStatusEnum(_CreateEnumTypeUponFirstAccess):
    AssetLinkStatus: str = ...

class AssetPerformanceLabelEnum(_CreateEnumTypeUponFirstAccess):
    AssetPerformanceLabel: str = ...

class AssetTypeEnum(_CreateEnumTypeUponFirstAccess):
    AssetType: str = ...

class AttributionModelEnum(_CreateEnumTypeUponFirstAccess):
    AttributionModel: str = ...

class AuthenticationErrorEnum(_CreateEnumTypeUponFirstAccess):
    AuthenticationError: str = ...

class AuthorizationErrorEnum(_CreateEnumTypeUponFirstAccess):
    AuthorizationError: str = ...

class BatchJobErrorEnum(_CreateEnumTypeUponFirstAccess):
    BatchJobError: str = ...

class BatchJobStatusEnum(_CreateEnumTypeUponFirstAccess):
    BatchJobStatus: str = ...

class BidModifierSourceEnum(_CreateEnumTypeUponFirstAccess):
    BidModifierSource: str = ...

class BiddingErrorEnum(_CreateEnumTypeUponFirstAccess):
    BiddingError: str = ...

class BiddingSourceEnum(_CreateEnumTypeUponFirstAccess):
    BiddingSource: str = ...

class BiddingStrategyErrorEnum(_CreateEnumTypeUponFirstAccess):
    BiddingStrategyError: str = ...

class BiddingStrategyStatusEnum(_CreateEnumTypeUponFirstAccess):
    BiddingStrategyStatus: str = ...

class BiddingStrategyTypeEnum(_CreateEnumTypeUponFirstAccess):
    BiddingStrategyType: str = ...

class BillingSetupErrorEnum(_CreateEnumTypeUponFirstAccess):
    BillingSetupError: str = ...

class BillingSetupStatusEnum(_CreateEnumTypeUponFirstAccess):
    BillingSetupStatus: str = ...

class BrandSafetySuitabilityEnum(_CreateEnumTypeUponFirstAccess):
    BrandSafetySuitability: str = ...

class BudgetCampaignAssociationStatusEnum(_CreateEnumTypeUponFirstAccess):
    BudgetCampaignAssociationStatus: str = ...

class BudgetDeliveryMethodEnum(_CreateEnumTypeUponFirstAccess):
    BudgetDeliveryMethod: str = ...

class BudgetPeriodEnum(_CreateEnumTypeUponFirstAccess):
    BudgetPeriod: str = ...

class BudgetStatusEnum(_CreateEnumTypeUponFirstAccess):
    BudgetStatus: str = ...

class BudgetTypeEnum(_CreateEnumTypeUponFirstAccess):
    BudgetType: str = ...

class CallConversionReportingStateEnum(_CreateEnumTypeUponFirstAccess):
    CallConversionReportingState: str = ...

class CallPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    CallPlaceholderField: str = ...

class CalloutPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    CalloutPlaceholderField: str = ...

class CampaignBudgetErrorEnum(_CreateEnumTypeUponFirstAccess):
    CampaignBudgetError: str = ...

class CampaignCriterionErrorEnum(_CreateEnumTypeUponFirstAccess):
    CampaignCriterionError: str = ...

class CampaignCriterionStatusEnum(_CreateEnumTypeUponFirstAccess):
    CampaignCriterionStatus: str = ...

class CampaignDraftErrorEnum(_CreateEnumTypeUponFirstAccess):
    CampaignDraftError: str = ...

class CampaignDraftStatusEnum(_CreateEnumTypeUponFirstAccess):
    CampaignDraftStatus: str = ...

class CampaignErrorEnum(_CreateEnumTypeUponFirstAccess):
    CampaignError: str = ...

class CampaignExperimentErrorEnum(_CreateEnumTypeUponFirstAccess):
    CampaignExperimentError: str = ...

class CampaignExperimentStatusEnum(_CreateEnumTypeUponFirstAccess):
    CampaignExperimentStatus: str = ...

class CampaignExperimentTrafficSplitTypeEnum(_CreateEnumTypeUponFirstAccess):
    CampaignExperimentTrafficSplitType: str = ...

class CampaignExperimentTypeEnum(_CreateEnumTypeUponFirstAccess):
    CampaignExperimentType: str = ...

class CampaignFeedErrorEnum(_CreateEnumTypeUponFirstAccess):
    CampaignFeedError: str = ...

class CampaignServingStatusEnum(_CreateEnumTypeUponFirstAccess):
    CampaignServingStatus: str = ...

class CampaignSharedSetErrorEnum(_CreateEnumTypeUponFirstAccess):
    CampaignSharedSetError: str = ...

class CampaignSharedSetStatusEnum(_CreateEnumTypeUponFirstAccess):
    CampaignSharedSetStatus: str = ...

class CampaignStatusEnum(_CreateEnumTypeUponFirstAccess):
    CampaignStatus: str = ...

class ChangeClientTypeEnum(_CreateEnumTypeUponFirstAccess):
    ChangeClientType: str = ...

class ChangeEventErrorEnum(_CreateEnumTypeUponFirstAccess):
    ChangeEventError: str = ...

class ChangeEventResourceTypeEnum(_CreateEnumTypeUponFirstAccess):
    ChangeEventResourceType: str = ...

class ChangeStatusErrorEnum(_CreateEnumTypeUponFirstAccess):
    ChangeStatusError: str = ...

class ChangeStatusOperationEnum(_CreateEnumTypeUponFirstAccess):
    ChangeStatusOperation: str = ...

class ChangeStatusResourceTypeEnum(_CreateEnumTypeUponFirstAccess):
    ChangeStatusResourceType: str = ...

class ClickTypeEnum(_CreateEnumTypeUponFirstAccess):
    ClickType: str = ...

class CollectionSizeErrorEnum(_CreateEnumTypeUponFirstAccess):
    CollectionSizeError: str = ...

class CombinedAudienceStatusEnum(_CreateEnumTypeUponFirstAccess):
    CombinedAudienceStatus: str = ...

class ContentLabelTypeEnum(_CreateEnumTypeUponFirstAccess):
    ContentLabelType: str = ...

class ContextErrorEnum(_CreateEnumTypeUponFirstAccess):
    ContextError: str = ...

class ConversionActionCategoryEnum(_CreateEnumTypeUponFirstAccess):
    ConversionActionCategory: str = ...

class ConversionActionCountingTypeEnum(_CreateEnumTypeUponFirstAccess):
    ConversionActionCountingType: str = ...

class ConversionActionErrorEnum(_CreateEnumTypeUponFirstAccess):
    ConversionActionError: str = ...

class ConversionActionStatusEnum(_CreateEnumTypeUponFirstAccess):
    ConversionActionStatus: str = ...

class ConversionActionTypeEnum(_CreateEnumTypeUponFirstAccess):
    ConversionActionType: str = ...

class ConversionAdjustmentTypeEnum(_CreateEnumTypeUponFirstAccess):
    ConversionAdjustmentType: str = ...

class ConversionAdjustmentUploadErrorEnum(_CreateEnumTypeUponFirstAccess):
    ConversionAdjustmentUploadError: str = ...

class ConversionAttributionEventTypeEnum(_CreateEnumTypeUponFirstAccess):
    ConversionAttributionEventType: str = ...

class ConversionLagBucketEnum(_CreateEnumTypeUponFirstAccess):
    ConversionLagBucket: str = ...

class ConversionOrAdjustmentLagBucketEnum(_CreateEnumTypeUponFirstAccess):
    ConversionOrAdjustmentLagBucket: str = ...

class ConversionUploadErrorEnum(_CreateEnumTypeUponFirstAccess):
    ConversionUploadError: str = ...

class CountryCodeErrorEnum(_CreateEnumTypeUponFirstAccess):
    CountryCodeError: str = ...

class CriterionCategoryChannelAvailabilityModeEnum(_CreateEnumTypeUponFirstAccess):
    CriterionCategoryChannelAvailabilityMode: str = ...

class CriterionCategoryLocaleAvailabilityModeEnum(_CreateEnumTypeUponFirstAccess):
    CriterionCategoryLocaleAvailabilityMode: str = ...

class CriterionErrorEnum(_CreateEnumTypeUponFirstAccess):
    CriterionError: str = ...

class CriterionSystemServingStatusEnum(_CreateEnumTypeUponFirstAccess):
    CriterionSystemServingStatus: str = ...

class CriterionTypeEnum(_CreateEnumTypeUponFirstAccess):
    CriterionType: str = ...

class CurrencyCodeErrorEnum(_CreateEnumTypeUponFirstAccess):
    CurrencyCodeError: str = ...

class CustomAudienceErrorEnum(_CreateEnumTypeUponFirstAccess):
    CustomAudienceError: str = ...

class CustomAudienceMemberTypeEnum(_CreateEnumTypeUponFirstAccess):
    CustomAudienceMemberType: str = ...

class CustomAudienceStatusEnum(_CreateEnumTypeUponFirstAccess):
    CustomAudienceStatus: str = ...

class CustomAudienceTypeEnum(_CreateEnumTypeUponFirstAccess):
    CustomAudienceType: str = ...

class CustomInterestErrorEnum(_CreateEnumTypeUponFirstAccess):
    CustomInterestError: str = ...

class CustomInterestMemberTypeEnum(_CreateEnumTypeUponFirstAccess):
    CustomInterestMemberType: str = ...

class CustomInterestStatusEnum(_CreateEnumTypeUponFirstAccess):
    CustomInterestStatus: str = ...

class CustomInterestTypeEnum(_CreateEnumTypeUponFirstAccess):
    CustomInterestType: str = ...

class CustomPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    CustomPlaceholderField: str = ...

class CustomerClientLinkErrorEnum(_CreateEnumTypeUponFirstAccess):
    CustomerClientLinkError: str = ...

class CustomerErrorEnum(_CreateEnumTypeUponFirstAccess):
    CustomerError: str = ...

class CustomerFeedErrorEnum(_CreateEnumTypeUponFirstAccess):
    CustomerFeedError: str = ...

class CustomerManagerLinkErrorEnum(_CreateEnumTypeUponFirstAccess):
    CustomerManagerLinkError: str = ...

class CustomerMatchUploadKeyTypeEnum(_CreateEnumTypeUponFirstAccess):
    CustomerMatchUploadKeyType: str = ...

class CustomerPayPerConversionEligibilityFailureReasonEnum(
    _CreateEnumTypeUponFirstAccess
):
    CustomerPayPerConversionEligibilityFailureReason: str = ...

class CustomerUserAccessErrorEnum(_CreateEnumTypeUponFirstAccess):
    CustomerUserAccessError: str = ...

class DataDrivenModelStatusEnum(_CreateEnumTypeUponFirstAccess):
    DataDrivenModelStatus: str = ...

class DatabaseErrorEnum(_CreateEnumTypeUponFirstAccess):
    DatabaseError: str = ...

class DateErrorEnum(_CreateEnumTypeUponFirstAccess):
    DateError: str = ...

class DateRangeErrorEnum(_CreateEnumTypeUponFirstAccess):
    DateRangeError: str = ...

class DayOfWeekEnum(_CreateEnumTypeUponFirstAccess):
    DayOfWeek: str = ...

class DeviceEnum(_CreateEnumTypeUponFirstAccess):
    Device: str = ...

class DisplayAdFormatSettingEnum(_CreateEnumTypeUponFirstAccess):
    DisplayAdFormatSetting: str = ...

class DisplayUploadProductTypeEnum(_CreateEnumTypeUponFirstAccess):
    DisplayUploadProductType: str = ...

class DistanceBucketEnum(_CreateEnumTypeUponFirstAccess):
    DistanceBucket: str = ...

class DistinctErrorEnum(_CreateEnumTypeUponFirstAccess):
    DistinctError: str = ...

class DsaPageFeedCriterionFieldEnum(_CreateEnumTypeUponFirstAccess):
    DsaPageFeedCriterionField: str = ...

class EducationPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    EducationPlaceholderField: str = ...

class EnumErrorEnum(_CreateEnumTypeUponFirstAccess):
    EnumError: str = ...

class ExtensionFeedItemErrorEnum(_CreateEnumTypeUponFirstAccess):
    ExtensionFeedItemError: str = ...

class ExtensionSettingDeviceEnum(_CreateEnumTypeUponFirstAccess):
    ExtensionSettingDevice: str = ...

class ExtensionSettingErrorEnum(_CreateEnumTypeUponFirstAccess):
    ExtensionSettingError: str = ...

class ExtensionTypeEnum(_CreateEnumTypeUponFirstAccess):
    ExtensionType: str = ...

class ExternalConversionSourceEnum(_CreateEnumTypeUponFirstAccess):
    ExternalConversionSource: str = ...

class FeedAttributeOperation(_CreateEnumTypeUponFirstAccess):
    Operator: str = ...

class FeedAttributeReferenceErrorEnum(_CreateEnumTypeUponFirstAccess):
    FeedAttributeReferenceError: str = ...

class FeedAttributeTypeEnum(_CreateEnumTypeUponFirstAccess):
    FeedAttributeType: str = ...

class FeedErrorEnum(_CreateEnumTypeUponFirstAccess):
    FeedError: str = ...

class FeedItemErrorEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemError: str = ...

class FeedItemQualityApprovalStatusEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemQualityApprovalStatus: str = ...

class FeedItemQualityDisapprovalReasonEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemQualityDisapprovalReason: str = ...

class FeedItemSetErrorEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemSetError: str = ...

class FeedItemSetLinkErrorEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemSetLinkError: str = ...

class FeedItemSetStatusEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemSetStatus: str = ...

class FeedItemSetStringFilterTypeEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemSetStringFilterType: str = ...

class FeedItemStatusEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemStatus: str = ...

class FeedItemTargetDeviceEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemTargetDevice: str = ...

class FeedItemTargetErrorEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemTargetError: str = ...

class FeedItemTargetStatusEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemTargetStatus: str = ...

class FeedItemTargetTypeEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemTargetType: str = ...

class FeedItemValidationErrorEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemValidationError: str = ...

class FeedItemValidationStatusEnum(_CreateEnumTypeUponFirstAccess):
    FeedItemValidationStatus: str = ...

class FeedLinkStatusEnum(_CreateEnumTypeUponFirstAccess):
    FeedLinkStatus: str = ...

class FeedMappingCriterionTypeEnum(_CreateEnumTypeUponFirstAccess):
    FeedMappingCriterionType: str = ...

class FeedMappingErrorEnum(_CreateEnumTypeUponFirstAccess):
    FeedMappingError: str = ...

class FeedMappingStatusEnum(_CreateEnumTypeUponFirstAccess):
    FeedMappingStatus: str = ...

class FeedOriginEnum(_CreateEnumTypeUponFirstAccess):
    FeedOrigin: str = ...

class FeedStatusEnum(_CreateEnumTypeUponFirstAccess):
    FeedStatus: str = ...

class FieldErrorEnum(_CreateEnumTypeUponFirstAccess):
    FieldError: str = ...

class FieldMaskErrorEnum(_CreateEnumTypeUponFirstAccess):
    FieldMaskError: str = ...

class FlightPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    FlightPlaceholderField: str = ...

class FrequencyCapEventTypeEnum(_CreateEnumTypeUponFirstAccess):
    FrequencyCapEventType: str = ...

class FrequencyCapLevelEnum(_CreateEnumTypeUponFirstAccess):
    FrequencyCapLevel: str = ...

class FrequencyCapTimeUnitEnum(_CreateEnumTypeUponFirstAccess):
    FrequencyCapTimeUnit: str = ...

class FunctionErrorEnum(_CreateEnumTypeUponFirstAccess):
    FunctionError: str = ...

class FunctionParsingErrorEnum(_CreateEnumTypeUponFirstAccess):
    FunctionParsingError: str = ...

class GenderTypeEnum(_CreateEnumTypeUponFirstAccess):
    GenderType: str = ...

class GeoTargetConstantStatusEnum(_CreateEnumTypeUponFirstAccess):
    GeoTargetConstantStatus: str = ...

class GeoTargetConstantSuggestionErrorEnum(_CreateEnumTypeUponFirstAccess):
    GeoTargetConstantSuggestionError: str = ...

class GeoTargetingRestrictionEnum(_CreateEnumTypeUponFirstAccess):
    GeoTargetingRestriction: str = ...

class GeoTargetingTypeEnum(_CreateEnumTypeUponFirstAccess):
    GeoTargetingType: str = ...

class GoogleAdsFieldCategoryEnum(_CreateEnumTypeUponFirstAccess):
    GoogleAdsFieldCategory: str = ...

class GoogleAdsFieldDataTypeEnum(_CreateEnumTypeUponFirstAccess):
    GoogleAdsFieldDataType: str = ...

class HeaderErrorEnum(_CreateEnumTypeUponFirstAccess):
    HeaderError: str = ...

class HotelDateSelectionTypeEnum(_CreateEnumTypeUponFirstAccess):
    HotelDateSelectionType: str = ...

class HotelPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    HotelPlaceholderField: str = ...

class HotelPriceBucketEnum(_CreateEnumTypeUponFirstAccess):
    HotelPriceBucket: str = ...

class HotelRateTypeEnum(_CreateEnumTypeUponFirstAccess):
    HotelRateType: str = ...

class IdErrorEnum(_CreateEnumTypeUponFirstAccess):
    IdError: str = ...

class ImageErrorEnum(_CreateEnumTypeUponFirstAccess):
    ImageError: str = ...

class IncomeRangeTypeEnum(_CreateEnumTypeUponFirstAccess):
    IncomeRangeType: str = ...

class InteractionEventTypeEnum(_CreateEnumTypeUponFirstAccess):
    InteractionEventType: str = ...

class InteractionTypeEnum(_CreateEnumTypeUponFirstAccess):
    InteractionType: str = ...

class InternalErrorEnum(_CreateEnumTypeUponFirstAccess):
    InternalError: str = ...

class InvoiceErrorEnum(_CreateEnumTypeUponFirstAccess):
    InvoiceError: str = ...

class InvoiceTypeEnum(_CreateEnumTypeUponFirstAccess):
    InvoiceType: str = ...

class JobPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    JobPlaceholderField: str = ...

class KeywordMatchTypeEnum(_CreateEnumTypeUponFirstAccess):
    KeywordMatchType: str = ...

class KeywordPlanAdGroupErrorEnum(_CreateEnumTypeUponFirstAccess):
    KeywordPlanAdGroupError: str = ...

class KeywordPlanAdGroupKeywordErrorEnum(_CreateEnumTypeUponFirstAccess):
    KeywordPlanAdGroupKeywordError: str = ...

class KeywordPlanCampaignErrorEnum(_CreateEnumTypeUponFirstAccess):
    KeywordPlanCampaignError: str = ...

class KeywordPlanCampaignKeywordErrorEnum(_CreateEnumTypeUponFirstAccess):
    KeywordPlanCampaignKeywordError: str = ...

class KeywordPlanCompetitionLevelEnum(_CreateEnumTypeUponFirstAccess):
    KeywordPlanCompetitionLevel: str = ...

class KeywordPlanErrorEnum(_CreateEnumTypeUponFirstAccess):
    KeywordPlanError: str = ...

class KeywordPlanForecastIntervalEnum(_CreateEnumTypeUponFirstAccess):
    KeywordPlanForecastInterval: str = ...

class KeywordPlanIdeaErrorEnum(_CreateEnumTypeUponFirstAccess):
    KeywordPlanIdeaError: str = ...

class KeywordPlanNetworkEnum(_CreateEnumTypeUponFirstAccess):
    KeywordPlanNetwork: str = ...

class LabelErrorEnum(_CreateEnumTypeUponFirstAccess):
    LabelError: str = ...

class LabelStatusEnum(_CreateEnumTypeUponFirstAccess):
    LabelStatus: str = ...

class LanguageCodeErrorEnum(_CreateEnumTypeUponFirstAccess):
    LanguageCodeError: str = ...

class LeadFormCallToActionTypeEnum(_CreateEnumTypeUponFirstAccess):
    LeadFormCallToActionType: str = ...

class LeadFormDesiredIntentEnum(_CreateEnumTypeUponFirstAccess):
    LeadFormDesiredIntent: str = ...

class LeadFormFieldUserInputTypeEnum(_CreateEnumTypeUponFirstAccess):
    LeadFormFieldUserInputType: str = ...

class LeadFormPostSubmitCallToActionTypeEnum(_CreateEnumTypeUponFirstAccess):
    LeadFormPostSubmitCallToActionType: str = ...

class LegacyAppInstallAdAppStoreEnum(_CreateEnumTypeUponFirstAccess):
    LegacyAppInstallAdAppStore: str = ...

class LinkedAccountTypeEnum(_CreateEnumTypeUponFirstAccess):
    LinkedAccountType: str = ...

class ListOperationErrorEnum(_CreateEnumTypeUponFirstAccess):
    ListOperationError: str = ...

class ListingGroupTypeEnum(_CreateEnumTypeUponFirstAccess):
    ListingGroupType: str = ...

class LocalPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    LocalPlaceholderField: str = ...

class LocationExtensionTargetingCriterionFieldEnum(_CreateEnumTypeUponFirstAccess):
    LocationExtensionTargetingCriterionField: str = ...

class LocationGroupRadiusUnitsEnum(_CreateEnumTypeUponFirstAccess):
    LocationGroupRadiusUnits: str = ...

class LocationPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    LocationPlaceholderField: str = ...

class LocationSourceTypeEnum(_CreateEnumTypeUponFirstAccess):
    LocationSourceType: str = ...

class ManagerLinkErrorEnum(_CreateEnumTypeUponFirstAccess):
    ManagerLinkError: str = ...

class ManagerLinkStatusEnum(_CreateEnumTypeUponFirstAccess):
    ManagerLinkStatus: str = ...

class MatchingFunctionContextTypeEnum(_CreateEnumTypeUponFirstAccess):
    MatchingFunctionContextType: str = ...

class MatchingFunctionOperatorEnum(_CreateEnumTypeUponFirstAccess):
    MatchingFunctionOperator: str = ...

class MediaBundleErrorEnum(_CreateEnumTypeUponFirstAccess):
    MediaBundleError: str = ...

class MediaFileErrorEnum(_CreateEnumTypeUponFirstAccess):
    MediaFileError: str = ...

class MediaTypeEnum(_CreateEnumTypeUponFirstAccess):
    MediaType: str = ...

class MediaUploadErrorEnum(_CreateEnumTypeUponFirstAccess):
    MediaUploadError: str = ...

class MerchantCenterLinkStatusEnum(_CreateEnumTypeUponFirstAccess):
    MerchantCenterLinkStatus: str = ...

class MessagePlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    MessagePlaceholderField: str = ...

class MimeTypeEnum(_CreateEnumTypeUponFirstAccess):
    MimeType: str = ...

class MinuteOfHourEnum(_CreateEnumTypeUponFirstAccess):
    MinuteOfHour: str = ...

class MobileAppVendorEnum(_CreateEnumTypeUponFirstAccess):
    MobileAppVendor: str = ...

class MobileDeviceTypeEnum(_CreateEnumTypeUponFirstAccess):
    MobileDeviceType: str = ...

class MonthOfYearEnum(_CreateEnumTypeUponFirstAccess):
    MonthOfYear: str = ...

class MultiplierErrorEnum(_CreateEnumTypeUponFirstAccess):
    MultiplierError: str = ...

class MutateErrorEnum(_CreateEnumTypeUponFirstAccess):
    MutateError: str = ...

class NegativeGeoTargetTypeEnum(_CreateEnumTypeUponFirstAccess):
    NegativeGeoTargetType: str = ...

class NewResourceCreationErrorEnum(_CreateEnumTypeUponFirstAccess):
    NewResourceCreationError: str = ...

class NotAllowlistedErrorEnum(_CreateEnumTypeUponFirstAccess):
    NotAllowlistedError: str = ...

class NotEmptyErrorEnum(_CreateEnumTypeUponFirstAccess):
    NotEmptyError: str = ...

class NullErrorEnum(_CreateEnumTypeUponFirstAccess):
    NullError: str = ...

class OfflineUserDataJobErrorEnum(_CreateEnumTypeUponFirstAccess):
    OfflineUserDataJobError: str = ...

class OfflineUserDataJobFailureReasonEnum(_CreateEnumTypeUponFirstAccess):
    OfflineUserDataJobFailureReason: str = ...

class OfflineUserDataJobStatusEnum(_CreateEnumTypeUponFirstAccess):
    OfflineUserDataJobStatus: str = ...

class OfflineUserDataJobTypeEnum(_CreateEnumTypeUponFirstAccess):
    OfflineUserDataJobType: str = ...

class OperatingSystemVersionOperatorTypeEnum(_CreateEnumTypeUponFirstAccess):
    OperatingSystemVersionOperatorType: str = ...

class OperationAccessDeniedErrorEnum(_CreateEnumTypeUponFirstAccess):
    OperationAccessDeniedError: str = ...

class OperatorErrorEnum(_CreateEnumTypeUponFirstAccess):
    OperatorError: str = ...

class OptimizationGoalTypeEnum(_CreateEnumTypeUponFirstAccess):
    OptimizationGoalType: str = ...

class ParentalStatusTypeEnum(_CreateEnumTypeUponFirstAccess):
    ParentalStatusType: str = ...

class PartialFailureErrorEnum(_CreateEnumTypeUponFirstAccess):
    PartialFailureError: str = ...

class PaymentModeEnum(_CreateEnumTypeUponFirstAccess):
    PaymentMode: str = ...

class PaymentsAccountErrorEnum(_CreateEnumTypeUponFirstAccess):
    PaymentsAccountError: str = ...

class PlaceholderTypeEnum(_CreateEnumTypeUponFirstAccess):
    PlaceholderType: str = ...

class PlacementTypeEnum(_CreateEnumTypeUponFirstAccess):
    PlacementType: str = ...

class PolicyApprovalStatusEnum(_CreateEnumTypeUponFirstAccess):
    PolicyApprovalStatus: str = ...

class PolicyFindingErrorEnum(_CreateEnumTypeUponFirstAccess):
    PolicyFindingError: str = ...

class PolicyReviewStatusEnum(_CreateEnumTypeUponFirstAccess):
    PolicyReviewStatus: str = ...

class PolicyTopicEntryTypeEnum(_CreateEnumTypeUponFirstAccess):
    PolicyTopicEntryType: str = ...

class PolicyTopicEvidenceDestinationMismatchUrlTypeEnum(_CreateEnumTypeUponFirstAccess):
    PolicyTopicEvidenceDestinationMismatchUrlType: str = ...

class PolicyTopicEvidenceDestinationNotWorkingDeviceEnum(
    _CreateEnumTypeUponFirstAccess
):
    PolicyTopicEvidenceDestinationNotWorkingDevice: str = ...

class PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum(
    _CreateEnumTypeUponFirstAccess
):
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorType: str = ...

class PolicyValidationParameterErrorEnum(_CreateEnumTypeUponFirstAccess):
    PolicyValidationParameterError: str = ...

class PolicyViolationErrorEnum(_CreateEnumTypeUponFirstAccess):
    PolicyViolationError: str = ...

class PositiveGeoTargetTypeEnum(_CreateEnumTypeUponFirstAccess):
    PositiveGeoTargetType: str = ...

class PreferredContentTypeEnum(_CreateEnumTypeUponFirstAccess):
    PreferredContentType: str = ...

class PriceExtensionPriceQualifierEnum(_CreateEnumTypeUponFirstAccess):
    PriceExtensionPriceQualifier: str = ...

class PriceExtensionPriceUnitEnum(_CreateEnumTypeUponFirstAccess):
    PriceExtensionPriceUnit: str = ...

class PriceExtensionTypeEnum(_CreateEnumTypeUponFirstAccess):
    PriceExtensionType: str = ...

class PricePlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    PricePlaceholderField: str = ...

class ProductBiddingCategoryLevelEnum(_CreateEnumTypeUponFirstAccess):
    ProductBiddingCategoryLevel: str = ...

class ProductBiddingCategoryStatusEnum(_CreateEnumTypeUponFirstAccess):
    ProductBiddingCategoryStatus: str = ...

class ProductChannelEnum(_CreateEnumTypeUponFirstAccess):
    ProductChannel: str = ...

class ProductChannelExclusivityEnum(_CreateEnumTypeUponFirstAccess):
    ProductChannelExclusivity: str = ...

class ProductConditionEnum(_CreateEnumTypeUponFirstAccess):
    ProductCondition: str = ...

class ProductCustomAttributeIndexEnum(_CreateEnumTypeUponFirstAccess):
    ProductCustomAttributeIndex: str = ...

class ProductTypeLevelEnum(_CreateEnumTypeUponFirstAccess):
    ProductTypeLevel: str = ...

class PromotionExtensionDiscountModifierEnum(_CreateEnumTypeUponFirstAccess):
    PromotionExtensionDiscountModifier: str = ...

class PromotionExtensionOccasionEnum(_CreateEnumTypeUponFirstAccess):
    PromotionExtensionOccasion: str = ...

class PromotionPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    PromotionPlaceholderField: str = ...

class ProximityRadiusUnitsEnum(_CreateEnumTypeUponFirstAccess):
    ProximityRadiusUnits: str = ...

class QualityScoreBucketEnum(_CreateEnumTypeUponFirstAccess):
    QualityScoreBucket: str = ...

class QueryErrorEnum(_CreateEnumTypeUponFirstAccess):
    QueryError: str = ...

class QuotaErrorDetails(_CreateEnumTypeUponFirstAccess):
    QuotaRateScope: str = ...

class QuotaErrorEnum(_CreateEnumTypeUponFirstAccess):
    QuotaError: str = ...

class RangeErrorEnum(_CreateEnumTypeUponFirstAccess):
    RangeError: str = ...

class ReachPlanAdLengthEnum(_CreateEnumTypeUponFirstAccess):
    ReachPlanAdLength: str = ...

class ReachPlanAgeRangeEnum(_CreateEnumTypeUponFirstAccess):
    ReachPlanAgeRange: str = ...

class ReachPlanErrorEnum(_CreateEnumTypeUponFirstAccess):
    ReachPlanError: str = ...

class ReachPlanNetworkEnum(_CreateEnumTypeUponFirstAccess):
    ReachPlanNetwork: str = ...

class RealEstatePlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    RealEstatePlaceholderField: str = ...

class RecommendationErrorEnum(_CreateEnumTypeUponFirstAccess):
    RecommendationError: str = ...

class RecommendationTypeEnum(_CreateEnumTypeUponFirstAccess):
    RecommendationType: str = ...

class RegionCodeErrorEnum(_CreateEnumTypeUponFirstAccess):
    RegionCodeError: str = ...

class RequestErrorEnum(_CreateEnumTypeUponFirstAccess):
    RequestError: str = ...

class ResourceAccessDeniedErrorEnum(_CreateEnumTypeUponFirstAccess):
    ResourceAccessDeniedError: str = ...

class ResourceChangeOperationEnum(_CreateEnumTypeUponFirstAccess):
    ResourceChangeOperation: str = ...

class ResourceCountLimitExceededErrorEnum(_CreateEnumTypeUponFirstAccess):
    ResourceCountLimitExceededError: str = ...

class ResponseContentTypeEnum(_CreateEnumTypeUponFirstAccess):
    ResponseContentType: str = ...

class SearchEngineResultsPageTypeEnum(_CreateEnumTypeUponFirstAccess):
    SearchEngineResultsPageType: str = ...

class SearchTermMatchTypeEnum(_CreateEnumTypeUponFirstAccess):
    SearchTermMatchType: str = ...

class SearchTermTargetingStatusEnum(_CreateEnumTypeUponFirstAccess):
    SearchTermTargetingStatus: str = ...

class ServedAssetFieldTypeEnum(_CreateEnumTypeUponFirstAccess):
    ServedAssetFieldType: str = ...

class SettingErrorEnum(_CreateEnumTypeUponFirstAccess):
    SettingError: str = ...

class SharedCriterionErrorEnum(_CreateEnumTypeUponFirstAccess):
    SharedCriterionError: str = ...

class SharedSetErrorEnum(_CreateEnumTypeUponFirstAccess):
    SharedSetError: str = ...

class SharedSetStatusEnum(_CreateEnumTypeUponFirstAccess):
    SharedSetStatus: str = ...

class SharedSetTypeEnum(_CreateEnumTypeUponFirstAccess):
    SharedSetType: str = ...

class SimulationModificationMethodEnum(_CreateEnumTypeUponFirstAccess):
    SimulationModificationMethod: str = ...

class SimulationTypeEnum(_CreateEnumTypeUponFirstAccess):
    SimulationType: str = ...

class SitelinkPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    SitelinkPlaceholderField: str = ...

class SizeLimitErrorEnum(_CreateEnumTypeUponFirstAccess):
    SizeLimitError: str = ...

class SlotEnum(_CreateEnumTypeUponFirstAccess):
    Slot: str = ...

class SpendingLimitTypeEnum(_CreateEnumTypeUponFirstAccess):
    SpendingLimitType: str = ...

class StringFormatErrorEnum(_CreateEnumTypeUponFirstAccess):
    StringFormatError: str = ...

class StringLengthErrorEnum(_CreateEnumTypeUponFirstAccess):
    StringLengthError: str = ...

class StructuredSnippetPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    StructuredSnippetPlaceholderField: str = ...

class SummaryRowSettingEnum(_CreateEnumTypeUponFirstAccess):
    SummaryRowSetting: str = ...

class SystemManagedResourceSourceEnum(_CreateEnumTypeUponFirstAccess):
    SystemManagedResourceSource: str = ...

class TargetCpaOptInRecommendationGoalEnum(_CreateEnumTypeUponFirstAccess):
    TargetCpaOptInRecommendationGoal: str = ...

class TargetImpressionShareLocationEnum(_CreateEnumTypeUponFirstAccess):
    TargetImpressionShareLocation: str = ...

class TargetRestrictionOperation(_CreateEnumTypeUponFirstAccess):
    Operator: str = ...

class TargetingDimensionEnum(_CreateEnumTypeUponFirstAccess):
    TargetingDimension: str = ...

class ThirdPartyAppAnalyticsLinkErrorEnum(_CreateEnumTypeUponFirstAccess):
    ThirdPartyAppAnalyticsLinkError: str = ...

class TimeTypeEnum(_CreateEnumTypeUponFirstAccess):
    TimeType: str = ...

class TimeZoneErrorEnum(_CreateEnumTypeUponFirstAccess):
    TimeZoneError: str = ...

class TrackingCodePageFormatEnum(_CreateEnumTypeUponFirstAccess):
    TrackingCodePageFormat: str = ...

class TrackingCodeTypeEnum(_CreateEnumTypeUponFirstAccess):
    TrackingCodeType: str = ...

class TravelPlaceholderFieldEnum(_CreateEnumTypeUponFirstAccess):
    TravelPlaceholderField: str = ...

class UrlFieldErrorEnum(_CreateEnumTypeUponFirstAccess):
    UrlFieldError: str = ...

class UserDataErrorEnum(_CreateEnumTypeUponFirstAccess):
    UserDataError: str = ...

class UserIdentifierSourceEnum(_CreateEnumTypeUponFirstAccess):
    UserIdentifierSource: str = ...

class UserInterestTaxonomyTypeEnum(_CreateEnumTypeUponFirstAccess):
    UserInterestTaxonomyType: str = ...

class UserListAccessStatusEnum(_CreateEnumTypeUponFirstAccess):
    UserListAccessStatus: str = ...

class UserListClosingReasonEnum(_CreateEnumTypeUponFirstAccess):
    UserListClosingReason: str = ...

class UserListCombinedRuleOperatorEnum(_CreateEnumTypeUponFirstAccess):
    UserListCombinedRuleOperator: str = ...

class UserListCrmDataSourceTypeEnum(_CreateEnumTypeUponFirstAccess):
    UserListCrmDataSourceType: str = ...

class UserListDateRuleItemOperatorEnum(_CreateEnumTypeUponFirstAccess):
    UserListDateRuleItemOperator: str = ...

class UserListErrorEnum(_CreateEnumTypeUponFirstAccess):
    UserListError: str = ...

class UserListLogicalRuleOperatorEnum(_CreateEnumTypeUponFirstAccess):
    UserListLogicalRuleOperator: str = ...

class UserListMembershipStatusEnum(_CreateEnumTypeUponFirstAccess):
    UserListMembershipStatus: str = ...

class UserListNumberRuleItemOperatorEnum(_CreateEnumTypeUponFirstAccess):
    UserListNumberRuleItemOperator: str = ...

class UserListPrepopulationStatusEnum(_CreateEnumTypeUponFirstAccess):
    UserListPrepopulationStatus: str = ...

class UserListRuleTypeEnum(_CreateEnumTypeUponFirstAccess):
    UserListRuleType: str = ...

class UserListSizeRangeEnum(_CreateEnumTypeUponFirstAccess):
    UserListSizeRange: str = ...

class UserListStringRuleItemOperatorEnum(_CreateEnumTypeUponFirstAccess):
    UserListStringRuleItemOperator: str = ...

class UserListTypeEnum(_CreateEnumTypeUponFirstAccess):
    UserListType: str = ...

class VanityPharmaDisplayUrlModeEnum(_CreateEnumTypeUponFirstAccess):
    VanityPharmaDisplayUrlMode: str = ...

class VanityPharmaTextEnum(_CreateEnumTypeUponFirstAccess):
    VanityPharmaText: str = ...

class WebpageConditionOperandEnum(_CreateEnumTypeUponFirstAccess):
    WebpageConditionOperand: str = ...

class WebpageConditionOperatorEnum(_CreateEnumTypeUponFirstAccess):
    WebpageConditionOperator: str = ...

class YoutubeVideoRegistrationErrorEnum(_CreateEnumTypeUponFirstAccess):
    YoutubeVideoRegistrationError: str = ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, overload as typing___overload

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.target_impression_share_location_pb2 import (
    TargetImpressionShareLocationEnum as google___ads___googleads___v6___enums___target_impression_share_location_pb2___TargetImpressionShareLocationEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Commission(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    commission_rate_micros: builtin___int = ...
    def __init__(
        self, *, commission_rate_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_commission_rate_micros",
            b"_commission_rate_micros",
            "commission_rate_micros",
            b"commission_rate_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_commission_rate_micros",
            b"_commission_rate_micros",
            "commission_rate_micros",
            b"commission_rate_micros",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_commission_rate_micros", b"_commission_rate_micros"
        ],
    ) -> typing_extensions___Literal["commission_rate_micros"]: ...

type___Commission = Commission

class EnhancedCpc(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___EnhancedCpc = EnhancedCpc

class ManualCpc(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    enhanced_cpc_enabled: builtin___bool = ...
    def __init__(
        self, *, enhanced_cpc_enabled: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_enhanced_cpc_enabled", b"_enhanced_cpc_enabled"
        ],
    ) -> typing_extensions___Literal["enhanced_cpc_enabled"]: ...

type___ManualCpc = ManualCpc

class ManualCpm(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___ManualCpm = ManualCpm

class ManualCpv(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___ManualCpv = ManualCpv

class MaximizeConversions(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    target_cpa: builtin___int = ...
    def __init__(
        self, *, target_cpa: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["target_cpa", b"target_cpa"]
    ) -> None: ...

type___MaximizeConversions = MaximizeConversions

class MaximizeConversionValue(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    target_roas: builtin___float = ...
    def __init__(
        self, *, target_roas: typing___Optional[builtin___float] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_target_roas", b"_target_roas", "target_roas", b"target_roas"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_target_roas", b"_target_roas", "target_roas", b"target_roas"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions___Literal["target_roas"]: ...

type___MaximizeConversionValue = MaximizeConversionValue

class TargetCpa(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    target_cpa_micros: builtin___int = ...
    cpc_bid_ceiling_micros: builtin___int = ...
    cpc_bid_floor_micros: builtin___int = ...
    def __init__(
        self,
        *,
        target_cpa_micros: typing___Optional[builtin___int] = None,
        cpc_bid_ceiling_micros: typing___Optional[builtin___int] = None,
        cpc_bid_floor_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_cpa_micros",
            b"target_cpa_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_cpa_micros",
            b"target_cpa_micros",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions___Literal["cpc_bid_ceiling_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cpc_bid_floor_micros", b"_cpc_bid_floor_micros"
        ],
    ) -> typing_extensions___Literal["cpc_bid_floor_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_target_cpa_micros", b"_target_cpa_micros"
        ],
    ) -> typing_extensions___Literal["target_cpa_micros"]: ...

type___TargetCpa = TargetCpa

class TargetCpm(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___TargetCpm = TargetCpm

class TargetImpressionShare(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    location: google___ads___googleads___v6___enums___target_impression_share_location_pb2___TargetImpressionShareLocationEnum.TargetImpressionShareLocationValue = ...
    location_fraction_micros: builtin___int = ...
    cpc_bid_ceiling_micros: builtin___int = ...
    def __init__(
        self,
        *,
        location: typing___Optional[
            google___ads___googleads___v6___enums___target_impression_share_location_pb2___TargetImpressionShareLocationEnum.TargetImpressionShareLocationValue
        ] = None,
        location_fraction_micros: typing___Optional[builtin___int] = None,
        cpc_bid_ceiling_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_location_fraction_micros",
            b"_location_fraction_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "location_fraction_micros",
            b"location_fraction_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_location_fraction_micros",
            b"_location_fraction_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "location",
            b"location",
            "location_fraction_micros",
            b"location_fraction_micros",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions___Literal["cpc_bid_ceiling_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_location_fraction_micros", b"_location_fraction_micros"
        ],
    ) -> typing_extensions___Literal["location_fraction_micros"]: ...

type___TargetImpressionShare = TargetImpressionShare

class TargetRoas(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    target_roas: builtin___float = ...
    cpc_bid_ceiling_micros: builtin___int = ...
    cpc_bid_floor_micros: builtin___int = ...
    def __init__(
        self,
        *,
        target_roas: typing___Optional[builtin___float] = None,
        cpc_bid_ceiling_micros: typing___Optional[builtin___int] = None,
        cpc_bid_floor_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_roas",
            b"_target_roas",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_roas",
            b"target_roas",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_roas",
            b"_target_roas",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_roas",
            b"target_roas",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions___Literal["cpc_bid_ceiling_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cpc_bid_floor_micros", b"_cpc_bid_floor_micros"
        ],
    ) -> typing_extensions___Literal["cpc_bid_floor_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions___Literal["target_roas"]: ...

type___TargetRoas = TargetRoas

class TargetSpend(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    target_spend_micros: builtin___int = ...
    cpc_bid_ceiling_micros: builtin___int = ...
    def __init__(
        self,
        *,
        target_spend_micros: typing___Optional[builtin___int] = None,
        cpc_bid_ceiling_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_target_spend_micros",
            b"_target_spend_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "target_spend_micros",
            b"target_spend_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_target_spend_micros",
            b"_target_spend_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "target_spend_micros",
            b"target_spend_micros",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions___Literal["cpc_bid_ceiling_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_target_spend_micros", b"_target_spend_micros"
        ],
    ) -> typing_extensions___Literal["target_spend_micros"]: ...

type___TargetSpend = TargetSpend

class PercentCpc(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    cpc_bid_ceiling_micros: builtin___int = ...
    enhanced_cpc_enabled: builtin___bool = ...
    def __init__(
        self,
        *,
        cpc_bid_ceiling_micros: typing___Optional[builtin___int] = None,
        enhanced_cpc_enabled: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions___Literal["cpc_bid_ceiling_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_enhanced_cpc_enabled", b"_enhanced_cpc_enabled"
        ],
    ) -> typing_extensions___Literal["enhanced_cpc_enabled"]: ...

type___PercentCpc = PercentCpc



from typing import Any

class KeywordPlanNegativeKeywordServiceStub:
    GetKeywordPlanNegativeKeyword: Any = ...
    MutateKeywordPlanNegativeKeywords: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanNegativeKeywordServiceServicer:
    def GetKeywordPlanNegativeKeyword(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlanNegativeKeywords(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanNegativeKeywordServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TextLabel(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    background_color: typing___Text = ...
    description: typing___Text = ...
    def __init__(
        self,
        *,
        background_color: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_background_color",
            b"_background_color",
            "_description",
            b"_description",
            "background_color",
            b"background_color",
            "description",
            b"description",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_background_color",
            b"_background_color",
            "_description",
            b"_description",
            "background_color",
            b"background_color",
            "description",
            b"description",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_background_color", b"_background_color"
        ],
    ) -> typing_extensions___Literal["background_color"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_description", b"_description"]
    ) -> typing_extensions___Literal["description"]: ...

type___TextLabel = TextLabel



# Stubs for google.ads.google_ads.v6.proto.enums.policy_topic_evidence_destination_not_working_device_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GeoTargetingTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    GeoTargetingTypeValue = typing___NewType("GeoTargetingTypeValue", builtin___int)
    type___GeoTargetingTypeValue = GeoTargetingTypeValue
    GeoTargetingType: _GeoTargetingType
    class _GeoTargetingType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            GeoTargetingTypeEnum.GeoTargetingTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 0)
        UNKNOWN = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 1)
        AREA_OF_INTEREST = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 2)
        LOCATION_OF_PRESENCE = typing___cast(
            GeoTargetingTypeEnum.GeoTargetingTypeValue, 3
        )
    UNSPECIFIED = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 0)
    UNKNOWN = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 1)
    AREA_OF_INTEREST = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 2)
    LOCATION_OF_PRESENCE = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 3)
    type___GeoTargetingType = GeoTargetingType
    def __init__(self,) -> None: ...

type___GeoTargetingTypeEnum = GeoTargetingTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordMatchTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    KeywordMatchTypeValue = typing___NewType("KeywordMatchTypeValue", builtin___int)
    type___KeywordMatchTypeValue = KeywordMatchTypeValue
    KeywordMatchType: _KeywordMatchType
    class _KeywordMatchType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            KeywordMatchTypeEnum.KeywordMatchTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 0)
        UNKNOWN = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 1)
        EXACT = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 2)
        PHRASE = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 3)
        BROAD = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 4)
    UNSPECIFIED = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 0)
    UNKNOWN = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 1)
    EXACT = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 2)
    PHRASE = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 3)
    BROAD = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 4)
    type___KeywordMatchType = KeywordMatchType
    def __init__(self,) -> None: ...

type___KeywordMatchTypeEnum = KeywordMatchTypeEnum



from typing import Any

class LanguageConstantServiceStub:
    GetLanguageConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class LanguageConstantServiceServicer:
    def GetLanguageConstant(self, request: Any, context: Any) -> None: ...

def add_LanguageConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
)
from google.rpc.status_pb2 import Status as google___rpc___status_pb2___Status
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.common.offline_user_data_pb2 import (
    UserData as google___ads___googleads___v4___common___offline_user_data_pb2___UserData,
)
from google.ads.google_ads.v4.proto.resources.offline_user_data_job_pb2 import (
    OfflineUserDataJob as google___ads___googleads___v4___resources___offline_user_data_job_pb2___OfflineUserDataJob,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CreateOfflineUserDataJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    @property
    def job(
        self,
    ) -> google___ads___googleads___v4___resources___offline_user_data_job_pb2___OfflineUserDataJob: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        job: typing___Optional[
            google___ads___googleads___v4___resources___offline_user_data_job_pb2___OfflineUserDataJob
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["job", b"job"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id", b"customer_id", "job", b"job"
        ],
    ) -> None: ...

type___CreateOfflineUserDataJobRequest = CreateOfflineUserDataJobRequest

class CreateOfflineUserDataJobResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___CreateOfflineUserDataJobResponse = CreateOfflineUserDataJobResponse

class GetOfflineUserDataJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetOfflineUserDataJobRequest = GetOfflineUserDataJobRequest

class RunOfflineUserDataJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___RunOfflineUserDataJobRequest = RunOfflineUserDataJobRequest

class AddOfflineUserDataJobOperationsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    @property
    def enable_partial_failure(
        self,
    ) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___OfflineUserDataJobOperation
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        enable_partial_failure: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        operations: typing___Optional[
            typing___Iterable[type___OfflineUserDataJobOperation]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "enable_partial_failure", b"enable_partial_failure"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "enable_partial_failure",
            b"enable_partial_failure",
            "operations",
            b"operations",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

type___AddOfflineUserDataJobOperationsRequest = AddOfflineUserDataJobOperationsRequest

class OfflineUserDataJobOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    remove_all: builtin___bool = ...
    @property
    def create(
        self,
    ) -> google___ads___googleads___v4___common___offline_user_data_pb2___UserData: ...
    @property
    def remove(
        self,
    ) -> google___ads___googleads___v4___common___offline_user_data_pb2___UserData: ...
    def __init__(
        self,
        *,
        create: typing___Optional[
            google___ads___googleads___v4___common___offline_user_data_pb2___UserData
        ] = None,
        remove: typing___Optional[
            google___ads___googleads___v4___common___offline_user_data_pb2___UserData
        ] = None,
        remove_all: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "remove_all",
            b"remove_all",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "remove_all",
            b"remove_all",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["create", "remove", "remove_all"]: ...

type___OfflineUserDataJobOperation = OfflineUserDataJobOperation

class AddOfflineUserDataJobOperationsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing___Optional[
            google___rpc___status_pb2___Status
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> None: ...

type___AddOfflineUserDataJobOperationsResponse = AddOfflineUserDataJobOperationsResponse



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.enums.google_ads_field_category_pb2 import (
    GoogleAdsFieldCategoryEnum as google___ads___googleads___v3___enums___google_ads_field_category_pb2___GoogleAdsFieldCategoryEnum,
)
from google.ads.google_ads.v3.proto.enums.google_ads_field_data_type_pb2 import (
    GoogleAdsFieldDataTypeEnum as google___ads___googleads___v3___enums___google_ads_field_data_type_pb2___GoogleAdsFieldDataTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GoogleAdsField(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    category: google___ads___googleads___v3___enums___google_ads_field_category_pb2___GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue = ...
    data_type: google___ads___googleads___v3___enums___google_ads_field_data_type_pb2___GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue = ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def selectable(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def filterable(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def sortable(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def selectable_with(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def attribute_resources(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def metrics(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def segments(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def enum_values(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def type_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def is_repeated(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        category: typing___Optional[
            google___ads___googleads___v3___enums___google_ads_field_category_pb2___GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue
        ] = None,
        selectable: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        filterable: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        sortable: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        selectable_with: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        attribute_resources: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        metrics: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        segments: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        enum_values: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        data_type: typing___Optional[
            google___ads___googleads___v3___enums___google_ads_field_data_type_pb2___GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue
        ] = None,
        type_url: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        is_repeated: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "filterable",
            b"filterable",
            "is_repeated",
            b"is_repeated",
            "name",
            b"name",
            "selectable",
            b"selectable",
            "sortable",
            b"sortable",
            "type_url",
            b"type_url",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "attribute_resources",
            b"attribute_resources",
            "category",
            b"category",
            "data_type",
            b"data_type",
            "enum_values",
            b"enum_values",
            "filterable",
            b"filterable",
            "is_repeated",
            b"is_repeated",
            "metrics",
            b"metrics",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "segments",
            b"segments",
            "selectable",
            b"selectable",
            "selectable_with",
            b"selectable_with",
            "sortable",
            b"sortable",
            "type_url",
            b"type_url",
        ],
    ) -> None: ...

type___GoogleAdsField = GoogleAdsField



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.resources.asset_pb2 import (
    Asset as google___ads___googleads___v3___resources___asset_pb2___Asset,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetAssetRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetAssetRequest = GetAssetRequest

class MutateAssetsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    @property
    def operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___AssetOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operations: typing___Optional[typing___Iterable[type___AssetOperation]] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id", b"customer_id", "operations", b"operations"
        ],
    ) -> None: ...

type___MutateAssetsRequest = MutateAssetsRequest

class AssetOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def create(
        self,
    ) -> google___ads___googleads___v3___resources___asset_pb2___Asset: ...
    def __init__(
        self,
        *,
        create: typing___Optional[
            google___ads___googleads___v3___resources___asset_pb2___Asset
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "create", b"create", "operation", b"operation"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "create", b"create", "operation", b"operation"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["create"]: ...

type___AssetOperation = AssetOperation

class MutateAssetsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___MutateAssetResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing___Optional[typing___Iterable[type___MutateAssetResult]] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["results", b"results"]
    ) -> None: ...

type___MutateAssetsResponse = MutateAssetsResponse

class MutateAssetResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___MutateAssetResult = MutateAssetResult



from typing import Any

class CustomerServiceStub:
    GetCustomer: Any = ...
    MutateCustomer: Any = ...
    ListAccessibleCustomers: Any = ...
    CreateCustomerClient: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerServiceServicer:
    def GetCustomer(self, request: Any, context: Any) -> None: ...
    def MutateCustomer(self, request: Any, context: Any) -> None: ...
    def ListAccessibleCustomers(self, request: Any, context: Any) -> None: ...
    def CreateCustomerClient(self, request: Any, context: Any) -> None: ...

def add_CustomerServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserListTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    UserListTypeValue = typing___NewType("UserListTypeValue", builtin___int)
    type___UserListTypeValue = UserListTypeValue
    UserListType: _UserListType
    class _UserListType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            UserListTypeEnum.UserListTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(UserListTypeEnum.UserListTypeValue, 0)
        UNKNOWN = typing___cast(UserListTypeEnum.UserListTypeValue, 1)
        REMARKETING = typing___cast(UserListTypeEnum.UserListTypeValue, 2)
        LOGICAL = typing___cast(UserListTypeEnum.UserListTypeValue, 3)
        EXTERNAL_REMARKETING = typing___cast(UserListTypeEnum.UserListTypeValue, 4)
        RULE_BASED = typing___cast(UserListTypeEnum.UserListTypeValue, 5)
        SIMILAR = typing___cast(UserListTypeEnum.UserListTypeValue, 6)
        CRM_BASED = typing___cast(UserListTypeEnum.UserListTypeValue, 7)
    UNSPECIFIED = typing___cast(UserListTypeEnum.UserListTypeValue, 0)
    UNKNOWN = typing___cast(UserListTypeEnum.UserListTypeValue, 1)
    REMARKETING = typing___cast(UserListTypeEnum.UserListTypeValue, 2)
    LOGICAL = typing___cast(UserListTypeEnum.UserListTypeValue, 3)
    EXTERNAL_REMARKETING = typing___cast(UserListTypeEnum.UserListTypeValue, 4)
    RULE_BASED = typing___cast(UserListTypeEnum.UserListTypeValue, 5)
    SIMILAR = typing___cast(UserListTypeEnum.UserListTypeValue, 6)
    CRM_BASED = typing___cast(UserListTypeEnum.UserListTypeValue, 7)
    type___UserListType = UserListType
    def __init__(self,) -> None: ...

type___UserListTypeEnum = UserListTypeEnum
